@@ -33,11 +33,12 @@ class Verifier:
     BATCH_QUERY = f"""
         SELECT v.id, identifier, verified_at, pubkey, metadata_id FROM verification as v
         LEFT JOIN events ON v.metadata_id = events.id
-        WHERE (verified_at + {Config.verification_expiration}) < unixepoch()
+        WHERE pubkey IS NOT NULL AND
+        (? - verified_at > {Config.verification_expiration})
         ORDER BY verified_at DESC
     """
-    FAILURE_QUERY = "UPDATE verification SET failed_at = unixepoch() WHERE id = ?"
-    SUCCESS_QUERY = "UPDATE verification SET verified_at = unixepoch() WHERE id = ?"
+    FAILURE_QUERY = "UPDATE verification SET failed_at = strftime('%s', 'now') WHERE id = ?"
+    SUCCESS_QUERY = "UPDATE verification SET verified_at = strftime('%s', 'now') WHERE id = ?"
 
     CREATE_TABLE = """
         CREATE TABLE IF NOT EXISTS verification (
@@ -146,9 +147,9 @@ class Verifier:
                 if (time.time() - last_run) > Config.verification_update_frequency:
                     async with db.cursor() as cursor:
                         try:
-                            await cursor.execute(self.BATCH_QUERY)
+                            await cursor.execute(self.BATCH_QUERY, (int(time.time()), ))
                         except Exception:
-                            log.exception('batch query %s', self.BATCH_QUERY)
+                            LOG.exception('batch query %s', self.BATCH_QUERY)
                             continue
                         async for row in cursor:
                             candidates.append(row)
@@ -169,7 +170,7 @@ class Verifier:
                         for vid, identifier, metadata_id in success:
                             if vid is None:
                                 # first time verifying
-                                await cursor.execute("INSERT INTO verification (identifier, metadata_id, verified_at) VALUES (?, ?, unixepoch())", (identifier, metadata_id))
+                                await cursor.execute("INSERT INTO verification (identifier, metadata_id, verified_at) VALUES (?, ?, strftime('%s', 'now'))", (identifier, metadata_id, ))
                             else:
                                 await cursor.execute(self.SUCCESS_QUERY, (vid, ))
                         for vid, identifier, metadata_id in failure:
@@ -178,7 +179,7 @@ class Verifier:
                                 continue
                             else:
                                 await cursor.execute(self.FAILURE_QUERY, (vid, ))
-                    await db.commit()
+                        await db.commit()
                     LOG.info("Saved success:%d failure:%d", len(success), len(failure))
             last_run = time.time()
 
